<?php
 
//
// phpBB 3.x configuration file
//
  
/*
 The Database Management System to use
 Any of: mysql, postgres, sqlite
 Other DBMSs not supported by Debian's dbconfig-common: mysql4, mssql, oracle, msaccess, mssql-odbc

 Note: use mysql4 only to enable transaction support, which you must enable
 in MySQL first. 'mysql' works fine with MySQL 4.x.
*/
$dbms = 'mysql';
   
/*
 In $dbhost, 'localhost' means local UNIX socket connection rather than TCP/IP
 to localhost. If you want the latter, write 127.0.0.1 or the equivalent of
 localhost.localdomain
*/
$dbhost = 'localhost';
$dbname = 'phpbb';
$dbuser = 'phpbb';
$dbpasswd = '';
    
$table_prefix = 'phpbb_';
$acm_type = 'file';

$url_forum = 'my.board';

define('PHPBB_INSTALLED', true);
